@@ -29,7 +29,7 @@ SUBROUTINE compute_scf( fii, lii, stat  )
   USE ions_base,        ONLY : tau, nat, nsp, ityp
   USE ener,             ONLY : etot
   USE force_mod,        ONLY : force
-  USE io_files,         ONLY : prefix, tmp_dir, iunupdate, seqopn, &
+  USE io_files,         ONLY : prefix, tmp_dir, wfc_dir,  iunupdate, seqopn, &
                                exit_file, iunexit, delete_if_present
   USE path_io_units_module, ONLY : iunpath
   USE path_formats,     ONLY : scf_fmt, scf_fmt_para
@@ -37,8 +37,9 @@ SUBROUTINE compute_scf( fii, lii, stat  )
                                istep_path, frozen, num_of_images, &
                                first_last_opt
   USE io_global,        ONLY : stdout, ionode, ionode_id, meta_ionode
-  USE mp_image_global_module,        ONLY : inter_image_comm, intra_image_comm, &
+  USE mp_global,        ONLY : inter_image_comm, intra_image_comm, &
                                my_image_id, nimage, root_image
+  USE mp_world,         ONLY : world_comm
   USE mp,               ONLY : mp_bcast, mp_barrier, mp_sum, mp_min
   USE path_io_routines, ONLY : new_image_init, get_new_image, &
                                stop_other_images
@@ -96,7 +97,7 @@ SUBROUTINE compute_scf( fii, lii, stat  )
   !
   ! ... all processes are syncronized (needed to have a readable output)
   !
-  CALL mp_barrier()
+  CALL mp_barrier( world_comm )
   !
   IF ( nimage > 1 .AND. .NOT.first_last_opt ) THEN
      !
@@ -134,7 +135,7 @@ SUBROUTINE compute_scf( fii, lii, stat  )
   ! ... only the first cpu initializes the file needed by parallelization
   ! ... among images
   !
-  IF ( meta_ionode ) CALL new_image_init( fii_, tmp_dir_saved )
+  IF ( meta_ionode ) CALL new_image_init( nimage, fii_, tmp_dir_saved )
   !
   image = fii_ + my_image_id
   !
@@ -152,7 +153,7 @@ SUBROUTINE compute_scf( fii, lii, stat  )
      !
      ! ... the new image is obtained (by ionode only)
      !
-     CALL get_new_image( image, tmp_dir_saved )
+     CALL get_new_image( nimage, image, tmp_dir_saved )
      !
      CALL mp_bcast( image, ionode_id, intra_image_comm )
      !
@@ -167,7 +168,7 @@ SUBROUTINE compute_scf( fii, lii, stat  )
   ! ... finalization of the job (this point is also reached in case of error
   ! ... condition)
   !
-1 CALL mp_barrier()
+1 CALL mp_barrier( world_comm )
   !
   DEALLOCATE( tauold )
   !
@@ -263,6 +264,7 @@ SUBROUTINE compute_scf( fii, lii, stat  )
       !
       tmp_dir = TRIM( tmp_dir_saved ) // TRIM( prefix ) // "_" // &
                 TRIM( int_to_char( image ) ) // "/"
+      wfc_dir = tmp_dir
       !
       ! ... unit stdout is connected to the appropriate file
       !
@@ -394,12 +396,6 @@ SUBROUTINE compute_scf( fii, lii, stat  )
          CLOSE( UNIT = iunupdate, STATUS = 'KEEP' )
          !
       END IF
-      !
-      ! ... input values are restored at the end of each iteration
-      ! ... ( they are modified by init_run ) - OBSOLETE?
-      !
-!      starting_pot = 'atomic'
-!      starting_wfc = 'file'
       !
       ethr = diago_thr_init
       !
