@@ -19,6 +19,7 @@ MODULE path_io_routines
   USE constants,  ONLY : pi, autoev, bohr_radius_angs, eV_to_kelvin
   USE io_global,  ONLY : meta_ionode, meta_ionode_id
   USE mp,         ONLY : mp_bcast
+  USE mp_world,   ONLY : world_comm
   !
   USE basic_algebra_routines
   !
@@ -335,23 +336,23 @@ MODULE path_io_routines
        !
        ! ... broadcast to all nodes
        !
-       CALL mp_bcast( istep_path,    meta_ionode_id )
-       CALL mp_bcast( nstep_path,    meta_ionode_id )
-       CALL mp_bcast( pending_image, meta_ionode_id )
+       CALL mp_bcast( istep_path,    meta_ionode_id, world_comm )
+       CALL mp_bcast( nstep_path,    meta_ionode_id, world_comm )
+       CALL mp_bcast( pending_image, meta_ionode_id, world_comm )
        !
-       CALL mp_bcast( pos,      meta_ionode_id )
-       CALL mp_bcast( fix_atom_pos,   meta_ionode_id )
-       CALL mp_bcast( pes,      meta_ionode_id )
-       CALL mp_bcast( grad_pes, meta_ionode_id )
+       CALL mp_bcast( pos,      meta_ionode_id, world_comm )
+       CALL mp_bcast( fix_atom_pos,   meta_ionode_id, world_comm )
+       CALL mp_bcast( pes,      meta_ionode_id, world_comm )
+       CALL mp_bcast( grad_pes, meta_ionode_id, world_comm )
        !
-       CALL mp_bcast( Emax,       meta_ionode_id )
-       CALL mp_bcast( Emin,       meta_ionode_id )
-       CALL mp_bcast( Emax_index, meta_ionode_id )
+       CALL mp_bcast( Emax,       meta_ionode_id, world_comm )
+       CALL mp_bcast( Emin,       meta_ionode_id, world_comm )
+       CALL mp_bcast( Emax_index, meta_ionode_id, world_comm )
        !
        IF ( lquick_min ) THEN
           !
-          CALL mp_bcast( frozen, meta_ionode_id )
-          CALL mp_bcast( posold, meta_ionode_id )
+          CALL mp_bcast( frozen, meta_ionode_id, world_comm )
+          CALL mp_bcast( posold, meta_ionode_id, world_comm )
           !
        END IF
        !
@@ -821,7 +822,7 @@ MODULE path_io_routines
      END SUBROUTINE write_output
      !
      !-----------------------------------------------------------------------
-     SUBROUTINE new_image_init( fii, outdir )
+     SUBROUTINE new_image_init( nimage, fii, outdir )
        !-----------------------------------------------------------------------
        !
        ! ... this subroutine initializes the file needed for the
@@ -830,11 +831,10 @@ MODULE path_io_routines
        USE path_io_units_module, ONLY : iunnewimage
        USE io_files, ONLY : prefix
        USE path_variables, ONLY : tune_load_balance
-       USE mp_image_global_module,      ONLY : nimage
        !
        IMPLICIT NONE
        !
-       INTEGER,          INTENT(IN) :: fii
+       INTEGER,          INTENT(IN) :: nimage, fii
        CHARACTER(LEN=*), INTENT(IN) :: outdir
        !
        !
@@ -852,7 +852,7 @@ MODULE path_io_routines
      END SUBROUTINE new_image_init
      !
      !-----------------------------------------------------------------------
-     SUBROUTINE get_new_image( image, outdir )
+     SUBROUTINE get_new_image( nimage, image, outdir )
        !-----------------------------------------------------------------------
        !
        ! ... this subroutine is used to get the new image to work on
@@ -862,10 +862,10 @@ MODULE path_io_routines
        USE io_files,       ONLY : iunnewimage, iunlock, prefix
        USE io_global,      ONLY : ionode
        USE path_variables, ONLY : tune_load_balance
-       USE mp_image_global_module,      ONLY : nimage
        !
        IMPLICIT NONE
        !
+       INTEGER,          INTENT(IN)    :: nimage
        INTEGER,          INTENT(INOUT) :: image
        CHARACTER(LEN=*), INTENT(IN)    :: outdir
        !
